#!/usr/bin/env node

/*
 Copyright Polyvi Inc. (http://polyvi.github.io/openxface)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

var coho = require('./coho'),
    reposet = require('./lib/reposet.js'),
    shelljs = require('shelljs'),
    fs = require('fs'),
    optimist = require('optimist'),
    path = require('path'),
    query = require('./lib/query.js');

function main() {
    coho.events.on('beforeCommandWillExec', function(command) {
        if (!command.keepCwd) {
            var reposetPath = reposet.root();
            if (reposetPath) {
                shelljs.cd(reposetPath);
            } else {
                console.warn('You don\'t have one reposet yet, ' +
                    'run "xsrc reposet -i -p" somewhere first!');
                process.exit(1);
            }
        }
    });

    var argv = optimist.boolean(['v', 'version']).argv;

    // if no command specified, version would be xsrc version, otherwise
    // it would be 'version' option for command, like prepare-release-branch
    if (!argv._[0] && (argv.v || argv.version)) {
        return console.log(require('./package').version);
    }

    // build commands from cmd subdir
    var commands = [];
    fs.readdirSync(path.join(__dirname, 'lib')).forEach(function(file) {
        var cmds = require('./lib/' + file).commands;
        if (cmds) {
            commands = commands.concat(cmds);
        }
    });

    // get repos info ready
    query.getGroups(function (err, groups) {
         if (err) {
             console.error(err);
             process.exit(1);
         } else {
             coho.init(groups);
             coho.exec(commands);
         }
    });
}

main();
